KnotError class

Represents a Knot originated error that occurred in the SDK.

Implemented types

Constructors

KnotError({required String errorCode, required String errorDescription})
Initializes a KnotError object.
KnotError.fromJson(dynamic json)
Factory method to create a KnotError from a json map.
factory

Properties

errorCode → String
Knot error code.
final
errorDescription → String
Human readable error description.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert class variables to Map representation.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited