KnotExit class

Represents a Knot event received during user or Knot SDK initiated exit from the flow.

Implemented types

Constructors

KnotExit()
Initializes a KnotExit object.
KnotExit.fromJson(dynamic json)
Factory method to create a KnotExit from a json map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert class variables to Map representation.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited