CustomerConfiguration class

Represents the customer configuration settings for the Knot SDK.

Constructors

CustomerConfiguration({String? cardName, String? customerName, String? logoId})
Constructs a CustomerConfiguration with optional parameters.

Properties

cardName → String?
The differentiated display name for the card product.
final
customerName → String?
The differentiated display name for the company.
final
hashCode → int
The hash code for this object.
no setterinherited
logoId → String?
The differentiated logo for the company.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts the CustomerConfiguration object to a JSON-compatible map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited