KnotapiFlutterPlatform class abstract

An abstract class defining the platform interface for the Knot API.

This class is used to define the contract for platform-specific implementations of the Knot API in Flutter.

Inheritance
  • Object
  • PlatformInterface
  • KnotapiFlutterPlatform
Implementers

Constructors

KnotapiFlutterPlatform()
Constructs a KnotapiFlutterPlatform instance.

Properties

hashCode → int
The hash code for this object.
no setterinherited
onObject → Stream<KnotObject>
A stream that emits KnotObject events from the platform implementation.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
Closes the Knot API session.
getSdkVersion() → Future<String>
getSdkVersion for Knot API.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(KnotConfiguration configuration) → Future<void>
Opens the Knot API session with the given configuration.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ KnotapiFlutterPlatform
Gets the current instance of KnotapiFlutterPlatform.
getter/setter pair