KnotapiFlutterWeb class

A web implementation of the KnotapiFlutterPlatform of the KnotapiFlutter plugin.

Inheritance

Constructors

KnotapiFlutterWeb()
Constructs a KnotapiFlutterWeb

Properties

hashCode → int
The hash code for this object.
no setterinherited
onObject → Stream<KnotObject>
A stream that emits KnotObject events from the platform implementation.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
Closes the Knot API session.
inherited
getPlatformVersion() → Future<String?>
Returns a String containing the version of the platform.
getSdkVersion() → Future<String>
getSdkVersion for Knot API.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(KnotConfiguration configuration) → Future<void>
Opens the Knot API session with the given configuration.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void