KnotEvent class

Implemented types

Constructors

KnotEvent({required String merchant, required String event, required String type, required String taskId, required bool sendCard})
KnotEvent.fromJson(dynamic json)
factory

Properties

event → String
final
hashCode → int
The hash code for this object.
no setterinherited
merchant → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendCard → bool
final
taskId → String
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited