KnotConfiguration class

Constructors

KnotConfiguration({required String sessionId, required String clientId, required String environment, List<int>? merchantIds, List<String>? domainUrls, bool? useCategories, String? entryPoint, bool? useSearch})

Properties

clientId ↔ String
getter/setter pair
domainUrls ↔ List<String>?
getter/setter pair
entryPoint ↔ String?
getter/setter pair
environment ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merchantIds ↔ List<int>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId ↔ String
getter/setter pair
useCategories ↔ bool?
getter/setter pair
useSearch ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited