MethodChannelKnotapiFlutter class

An implementation of KnotapiFlutterPlatform that uses method channels.

Inheritance

Properties

eventChannel → EventChannel
final
hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
onObject → Stream<KnotObject>
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

closeKnotSDK() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCardOnFileSwitcher(KnotConfiguration configuration) → Future<void>
override
openSubscriptionManager(KnotConfiguration configuration) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited